NAMES_DICTIONARY = {
    "No membrane cut, double MT": 0,
    "No membrane cut, simple MT": 1,
    "No membrane cut, no MT": 2,
    "Membrane cut, simple MT": 3,
    "Membrane cut, no MT": 4,
    "No membrane cut, double MT ?": 5,
    "No membrane cut, simple MT ?": 6,
    "No membrane cut, no MT ?": 7,
    "Membrane cut, simple MT ?": 8,
    "Membrane cut, no MT ?": 9,
}
